@@ -1,11 +1,11 @@
 """Implement core capabilities for classes."""
 from .__version__ import __version__
 
+from .auth.userkey import (UserKey)
+
 from .apikeyuser import (APIKeyUser)
-
 from .streamuser import (StreamUser)
-
 from .stream_response import (StreamResponse)
 
-__all__ = [APIKeyUser, StreamUser, StreamResponse, 'const', 'dicts', ]
+__all__ = [UserKey, APIKeyUser, StreamUser, StreamResponse, 'const', 'dicts', 'auth']
 version = __version__
